@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 #########################################################################
-#    Copyright (C) 2010 Sergio Villar Senin <svillar@igalia.com>
+#    Copyright (C) 2010, 2011 Sergio Villar Senin <svillar@igalia.com>
 #
 #    This file is part of ReSiStance
 #
@@ -26,7 +26,7 @@ import gtk
 
 RSS_NAME = 'ReSiStance'
 RSS_COMPACT_NAME = 'resistance'
-RSS_VERSION = '0.7'
+RSS_VERSION = '0.8'
 RSS_DESCRIPTION = 'ReSiStance is a RSS feeds reader'
 RSS_URL = 'http://www.igalia.com'
 
@@ -51,9 +51,8 @@ LOCALE_DIR = os.path.join(APP_DIR, 'locale')
 DEFAULT_LANGUAGES = os.environ.get('LANGUAGE', '').split(':')
 DEFAULT_LANGUAGES += ['en_US']
 
-SECONDARY_TEXT_COLOR = 'SecondaryTextColor'
-ACTIVE_TEXT_COLOR = 'ActiveTextColor'
-DEFAULT_TEXT_COLOR = 'DefaultTextColor'
+# Default RSS icon for feeds without favicon
+DEFAULT_FAVICON = os.path.join(APP_DIR, 'feed-presence.png')
 
 ICON_UP_NAME = "rss_reader_move_up"
 ICON_DOWN_NAME = "rss_reader_move_down"
@@ -62,3 +61,17 @@ ASCENDING_ORDER, DESCENDING_ORDER, VISITS_ORDER = range(3)
 font_size_range = range(12,28,4)
 
 MYDOCS_DIR = '/home/user/MyDocs/.documents'
+
+#Google Reader
+URL_LOGIN = "https://www.google.com/accounts/ClientLogin"
+GOOGLE_READER_ATOM_URL = 'http://www.google.com/reader/atom/'
+GOOGLE_READER_API_URL = 'http://www.google.com/reader/api/0/'
+URL_TOKEN = GOOGLE_READER_API_URL + 'token'
+URL_SUBSCRIPTION_LIST = GOOGLE_READER_API_URL + 'subscription/list?output=xml&client=-'
+URL_FEED = GOOGLE_READER_ATOM_URL + 'feed/'
+URL_USER = GOOGLE_READER_ATOM_URL + 'user/-/'
+LABEL_SUFFIX = "label/"
+STATE_SUFFIX = "state/com.google/"
+URL_EDIT = GOOGLE_READER_API_URL + 'edit-tag?client=-'
+URL_SUBSCRIPTION_EDIT = GOOGLE_READER_API_URL + 'subscription/edit'
+GOOGLE_READER_ICON_FILE = os.path.join(APP_DIR, 'prism-google-reader.png')
